@@ -104,6 +104,7 @@ public:
    * @return A boolean indicating success
    */
   bool saveDocument(const QUrl& url, bool force = false);
+  bool saveDocumentTemplate(const QUrl& url, const QString& collTitle);
   /**
    * Closes the document, deleting the contents. The return value is presently always true.
    *
@@ -134,7 +135,7 @@ public:
    * @param coll A pointer to the appended collection.
    * @param structuralChange A flag indicating a structural change was made to the database
    */
-  void appendCollection(CollPtr coll, bool* structuralChange);
+  void appendCollection(CollPtr coll);
   static void appendCollection(CollPtr targetColl, CollPtr sourceColl, bool* structuralChange);
   /**
    * Merges another collection into this one. The collections must be the same type. Fields in the
@@ -145,7 +146,7 @@ public:
    * @param structuralChange A flag indicating a structural change was made to the database
    * @return A QPair of the merged entries, see note in datavectors.h
    */
-  MergePair mergeCollection(CollPtr coll, bool* structuralChange);
+  MergePair mergeCollection(CollPtr coll);
   static MergePair mergeCollection(CollPtr targetColl, CollPtr sourceColl, bool* structuralChange);
   /**
    * Replace the current collection with a new one. Effectively, this is equivalent to opening
@@ -199,6 +200,7 @@ Q_SIGNALS:
   void signalCollectionImagesLoaded(Tellico::Data::CollPtr coll);
   void signalCollectionAdded(Tellico::Data::CollPtr coll);
   void signalCollectionDeleted(Tellico::Data::CollPtr coll);
+  void signalCollectionModified(Tellico::Data::CollPtr coll, bool structuralChange);
 
 private Q_SLOTS:
   /**
