@@ -37,7 +37,6 @@
 #include <QFile>
 #include <QTextStream>
 #include <QGridLayout>
-#include <QTextCodec>
 #include <QUrlQuery>
 
 namespace {
@@ -66,7 +65,7 @@ QString RPGGeekFetcher::source() const {
 
 // https://boardgamegeek.com/wiki/page/XML_API_Terms_of_Use
 QString RPGGeekFetcher::attribution() const {
-  return i18n(providedBy, QLatin1String("https://boardgamegeek.com"), QLatin1String("BoardGameGeek"));
+  return TC_I18N3(providedBy, QLatin1String("https://boardgamegeek.com"), QLatin1String("BoardGameGeek"));
 }
 
 bool RPGGeekFetcher::canSearch(Fetch::FetchKey k) const {
@@ -141,7 +140,6 @@ Tellico::Data::EntryPtr RPGGeekFetcher::fetchEntryHookData(Data::EntryPtr entry_
   QFile f(QStringLiteral("/tmp/test-rpggeek.xml"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
-    t.setCodec("UTF-8");
     t << output;
   }
   f.close();
@@ -166,10 +164,14 @@ Tellico::Data::EntryPtr RPGGeekFetcher::fetchEntryHookData(Data::EntryPtr entry_
   if(coll->entryCount() > 1) {
     myDebug() << "weird, more than one entry found";
   }
+  // replace HTML entities
+  static const QString desc(QStringLiteral("description"));
+  auto entry = coll->entries().front();
+  entry->setField(desc, Tellico::decodeHTML(entry->field(desc)));
 
   // don't want to include id
   coll->removeField(QStringLiteral("bggid"));
-  return coll->entries().front();
+  return entry;
 }
 
 Tellico::Fetch::FetchRequest RPGGeekFetcher::updateRequest(Data::EntryPtr entry_) {
