@@ -201,7 +201,7 @@ void TVmazeFetcher::slotComplete(KJob* job_) {
   }
 
   int count = 0;
-  foreach(const QJsonValue& result, results) {
+  for(const QJsonValue& result : results) {
     Data::EntryPtr entry(new Data::Entry(coll));
     populateEntry(entry, result.toObject().value(QLatin1String("show"))
                                .toObject().toVariantMap(), false);
