@@ -56,13 +56,13 @@ class DateWidget::DatePickerAction : public QWidgetAction
     }
 
   protected:
-    QWidget *createWidget( QWidget *parent ) Q_DECL_OVERRIDE
+    QWidget *createWidget( QWidget *parent ) override
     {
       mDatePicker->setParent( parent );
       return mDatePicker;
     }
 
-    void deleteWidget( QWidget *widget ) Q_DECL_OVERRIDE
+    void deleteWidget( QWidget *widget ) override
     {
       if ( widget != mDatePicker ) {
         return;
