@@ -60,6 +60,10 @@ void FilmAffinityFetcherTest::testSuperman() {
 
   QCOMPARE(results.size(), 1);
 
+  // verify the search results contain no html
+  QVERIFY(!m_resultTitles.isEmpty());
+  QCOMPARE(m_resultTitles.at(0), QStringLiteral("Superman Returns"));
+
   // the first entry had better be the right one
   Tellico::Data::EntryPtr entry = results.at(0);
 
@@ -82,7 +86,6 @@ void FilmAffinityFetcherTest::testSuperman() {
   QCOMPARE(entry->field("filmaffinity"), QStringLiteral("https://www.filmaffinity.com/us/film300630.html"));
 }
 
-
 void FilmAffinityFetcherTest::testSupermanES() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Video, Tellico::Fetch::Title, QStringLiteral("Superman Returns"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::FilmAffinityFetcher(this));
@@ -158,7 +161,7 @@ void FilmAffinityFetcherTest::testAlcarras() {
   QCOMPARE(entry->field("director"), QString::fromUtf8("Carla Simón"));
   QCOMPARE(entry->field("writer"), QString::fromUtf8("Carla Simón; Arnau Vilaró"));
   QCOMPARE(entry->field("composer"), QStringLiteral("Andrea Koch"));
-  QCOMPARE(entry->field("studio"), QString::fromUtf8("Avalon P.C; Elastica Films; Vilaüt Films; Kino Produzioni; Movistar Plus+; Rtve; TV3"));
+  QCOMPARE(entry->field("studio"), QString::fromUtf8("Avalon; Elastica Films; Vilaüt Films; Kino Produzioni; Movistar Plus+; RTVE; TV3"));
   QCOMPARE(set(entry, "genre"), set(QStringLiteral("Drama")));
   QCOMPARE(entry->field("running-time"), QStringLiteral("120"));
   QStringList castList = Tellico::FieldFormat::splitTable(entry->field(QStringLiteral("cast")));
