@@ -38,8 +38,10 @@ private Q_SLOTS:
   void testAuthor();
   void testIsbn();
   void testIsbn13();
+  void testLccn();
   void testMultipleIsbn();
   void testUpdate();
+  void testComic();
 };
 
 #endif
