@@ -32,7 +32,6 @@
 #include "../collections/bookcollection.h"
 #include "../collectionfactory.h"
 #include "../images/imagefactory.h"
-#include "../fieldformat.h"
 #include "../utils/datafileregistry.h"
 
 #include <KLocalizedString>
@@ -56,6 +55,8 @@ void PdfTest::initTestCase() {
 void PdfTest::testScienceDirect() {
   QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-sciencedirect.pdf"));
   Tellico::Import::PDFImporter importer(url);
+  QVERIFY(importer.canImport(Tellico::Data::Collection::Book));
+  QVERIFY(importer.canImport(Tellico::Data::Collection::Bibtex));
 
   Tellico::Data::CollPtr coll = importer.collection();
 
