@@ -53,7 +53,7 @@ public:
    * @param pos The position of the cursor
    * @return The condition of the text
    */
-  virtual QValidator::State validate(QString& input, int& pos) const Q_DECL_OVERRIDE;
+  virtual QValidator::State validate(QString& input, int& pos) const override;
 
   /**
    * The input string is examined. Hyphens are inserted appropriately,
@@ -125,7 +125,7 @@ public:
    *
    * @param input The raw string, hyphens included
    */
-  virtual void fixup(QString& input) const Q_DECL_OVERRIDE;
+  virtual void fixup(QString& input) const override;
 
   static void staticFixup(QString& input);
   static void fixup10(QString& input);
