@@ -237,3 +237,14 @@ QString Tellico::removeControlCodes(const QString& string) {
   }
   return result;
 }
+
+QByteArray Tellico::localeEncodingName() {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+  return QTextCodec::codecForLocale()->name();
+#else
+// Bug 493180: QStringConverter::nameForEncoding(QStringConverter::System) returns "Locale" which is not what we want
+// return UTF-8 instead
+  const auto encName = QStringConverter::nameForEncoding(QStringConverter::System);
+  return (qstrcmp(encName, "Locale") == 0) ? "UTF-8" : encName;
+#endif
+}
