@@ -56,17 +56,16 @@ QValidator::State UPCValidator::validate(QString& input_, int& pos_) const {
 
   // once it gets converted to an ISBN, remember that, and use it for later
   if(input_.startsWith(QLatin1String("978")) || input_.startsWith(QLatin1String("979"))) {
-    ISBNValidator val(0);
+    ISBNValidator val;
     QValidator::State s = val.validate(input_, pos_);
     if(s == QValidator::Acceptable) {
       m_isbn = true;
-      // bad hack
-      UPCValidator* that = const_cast<UPCValidator*>(this);
-      that->signalISBN();
+      emit signalISBN();
     }
     return s;
   }
 
+  // TODO: return QValidator::Acceptable if check sum is correct
   return QValidator::Intermediate;
 }
 
@@ -88,13 +87,11 @@ void UPCValidator::fixup(QString& input_) const {
   const uint len = input_.length();
   if(len > 12 && (input_.startsWith(QLatin1String("978")) || input_.startsWith(QLatin1String("979")))) {
     QString s = input_;
-    ISBNValidator val(0);
+    ISBNValidator val;
     int p = 0;
     int state = val.validate(s, p);
     if(state == QValidator::Acceptable) {
-      // bad hack
-      UPCValidator* that = const_cast<UPCValidator*>(this);
-      that->signalISBN();
+      emit signalISBN();
       input_ = s;
     }
   }
@@ -138,4 +135,3 @@ QValidator::State Tellico::CueCat::decode(QString& input_) {
   input_ = code;
   return QValidator::Acceptable;
 }
-
